@@ -1,9 +1,9 @@
-import collections
+import collections.abc
 
 
 def deep_update(source, overrides):
     for key, value in overrides.items():
-        if isinstance(value, collections.Mapping) and value:
+        if isinstance(value, collections.abc.Mapping) and value:
             returned = deep_update(source.get(key, {}), value)
             source[key] = returned
         else:
